@@ -14,15 +14,15 @@
 
 #include "suprocess.h"
 #include "kcookie_p.h"
+#include <ksu_debug.h>
 
-#include <QtCore/QFile>
-#include <QDebug>
+#include <QFile>
 #include <QStandardPaths>
 #include <qplatformdefs.h>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <kuser.h>
 
 #ifdef KDESU_USE_SUDO_DEFAULT
@@ -52,7 +52,7 @@ SuProcess::SuProcess(const QByteArray &user, const QByteArray &command)
     d->superUserCommand = group.readEntry("super-user-command", DEFAULT_SUPER_USER_COMMAND);
 
     if (d->superUserCommand != QLatin1String("sudo") && d->superUserCommand != QLatin1String("su")) {
-        qWarning() << "unknown super user command.";
+        qCWarning(KSU_LOG) << "unknown super user command.";
         d->superUserCommand = DEFAULT_SUPER_USER_COMMAND;
     }
 }
@@ -116,10 +116,16 @@ int SuProcess::exec(const char *password, int check)
     if (d->superUserCommand == QLatin1String("su")) {
         args += "-c";
     }
-    args += QByteArray(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5) + "/kdesu_stub";
+    // Get the kdesu_stub and su command from a config file if set, used in test
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group(config, "super-user-command");
+    const QString defaultPath = QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5) + QStringLiteral("/kdesu_stub");
+    const QString kdesuStubPath = group.readEntry("kdesu_stub_path", defaultPath);
+    args += kdesuStubPath.toLocal8Bit();
     args += "-"; // krazy:exclude=doublequote_chars (QList, not QString)
 
-    const QByteArray command = QFile::encodeName(QStandardPaths::findExecutable(d->superUserCommand));
+    const QString commandString = group.readEntry("command", QStandardPaths::findExecutable(d->superUserCommand));
+    const QByteArray command = commandString.toLocal8Bit();
     if (command.isEmpty()) {
         return check ? SuNotFound : -1;
     }
@@ -132,7 +138,7 @@ int SuProcess::exec(const char *password, int check)
 
     if (ret == error) {
         if (!check) {
-            qCritical() << "[" << __FILE__ << ":" << __LINE__ << "] " << "Conversation with su failed.";
+            qCCritical(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "Conversation with su failed.";
         }
         return ret;
     }
@@ -172,7 +178,7 @@ int SuProcess::exec(const char *password, int check)
     int iret = converseStub(check);
     if (iret < 0) {
         if (!check) {
-            qCritical() << "[" << __FILE__ << ":" << __LINE__ << "] " << "Conversation with kdesu_stub failed.";
+            qCCritical(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "Conversation with kdesu_stub failed.";
         }
         return iret;
     } else if (iret == 1) {
@@ -203,7 +209,8 @@ int SuProcess::converseSU(const char *password)
     QByteArray line;
     while (true) {
         line = readLine();
-        if (line.isNull()) {
+        // return if problem. sudo checks for a second prompt || su gets a blank line
+        if ((line.contains(':') && state != WaitForPrompt) || line.isNull()) {
             return (state == HandleStub ? notauthorized : error);
         }
 
